# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class NudProvidersController < Hermes::Api::Dmo::ApplicationController
        before_action :check_if_allowed, only: %i[create update delete]
        before_action :set_instance_from_postal_code, only: [:show]
        
        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ]

        ACCEPTABLE_PARAMS = %w[
        ]

        REGEX_PARAMS = %w[
        ]

        MUTATE_PARAMS = %i[
          department_codes
          name
          url
          info_message
        ]
        mutate_params_only(*MUTATE_PARAMS)

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end
        

        def set_instance_from_postal_code
          case params[:id].length
          when 6,7
            code = params[:id].length ==6 ? params[:id][0..1] : params[:id][0..2]
            @instance = Hermes::NudProvider.find_by(department_codes: code)
            specific_error = true
          when 2,3
            @instance = Hermes::NudProvider.find_by(department_codes: params[:id])
            specific_error = true
          else
            @instance = Hermes::NudProvider.find(params[:id])
          end
          
           if specific_error == true 
             render_json_error(:not_found, ("Aucun département trouvé pour le code " + params[:id].to_s).to_sym ) unless  @instance
           end
        end

        def check_if_allowed
          return render_json_error(:unauthorized, :only_administrators_are_allowed_to_interact_with_untensed_areas) unless current_user_roles.include?('Administrator')
        end
      end
    end
  end
end
