# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class SignupUserNotificationPreferencesController < Hermes::Api::Dmo::ApplicationController
        skip_before_filter :verify_authenticity_token, :set_user, :allow_true_user, :check_if_log_as
        skip_after_action :log_action

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          email
          notification_key
          want_to_be_subscribed
          used_at
        ].freeze

        REGEX_PARAMS = %w[
          email
        ].freeze

        MUTATE_PARAMS = %i[
          email
          notification_key
          want_to_be_subscribed
        ].freeze

        mutate_params_only(*MUTATE_PARAMS)

        def create
          @instance = @model.new(mutate_valid_params)
          return respond_with_errors(@instance) unless @instance.save

          render(jsonapi: @instance, serializer: @serializer, status: :created)
        end

        def create_multiple_preferences
          email = params[:data][:attributes][:email]
          created_instance_ids = []
          done_keys = []

          params[:data][:attributes][:notifs].each do|notif|
            notif[:email] = email
            done_keys.push(notif[:notification_key])
            notif_valid_params = ActiveModelSerializers::Deserialization.jsonapi_parse!(
              {"data"=>{"attributes"=> notif }},
              only: @@mutate_params_only, key_transform: :unaltered
            ).merge(@additional_params)

            instance = Hermes::SignupUserNotificationPreference.new(notif_valid_params)
            return respond_with_errors(instance) unless instance.save
            created_instance_ids.push (instance.id.to_s)
        end
         
          render(json: {email: email, signup_user_notification_preference_ids: created_instance_ids}, status: :created)
        end

        def user_notifications_list 
          render(json: NOTIFICATION_KEYS[:user])
        end 

      end
    end
  end
end
