# frozen_string_literal: true

module Hermes
  module BoClient
    # extending Mapping Module from base_map.rb
    module Mappings
      # handle HousingOffer model mapping for xml data send
      class HousingOfferMap
        include Hermes::BoClient::Mappings::Concerns::BaseMap
        
        def initialize(options)
          housing_offer_id = options[:housing_offer_id]
          applicant_id = options[:applicant_id]
          @main_object = Hermes::HousingOffer.find_by(id: housing_offer_id)
          
          self.main_object = @main_object
          unless main_object
            raise ArgumentError, "Offer with #{housing_offer_id} doesn't exists."
          end
          
          @agency = Hermes::Entity.find_by(id: main_object.agency_id)
          unless applicant_id.nil?
            @applicant = Hermes::Applicant.find_by(id: applicant_id)
          end
          
          @map = {
            
            'SIREN_bailleur': 'lessor.siren',
            # 'libelle_organisme': 'lessor.title',
            
            
            'reference_offre': 'id',
            'code_territoire': "lessor_code",
            'reference': 'external_ref',
            
            'texte': 'description',
            
            
            'code_postal': 'postal_code',
            'departement': 'department',
            
            
            'libelle_residence': 'residence_title',
            'latitude': 'latitude',
            'longitude': 'longitude',
            'type_construction': 'construction_type',
            'nature': 'kind',
            'type': 'typology',
            'dpe_etiquette_ges': 'dpe_ges',
            'dpe_etiquette_conso': 'dpe_conso',
            'zone_plafond_ressources': 'threshold_subtype',
            'type_chauffage': 'heating_type',
            'eau_chaude_distribution': 'hot_water_distribution', # missing from import
            'nature_stationnement': 'parking_type',
            'visite_virtuelle': 'virtual_visit',
            'type_cuisine': 'kitchen_type',
            'loyer_mensuel': 'rent_amount',
            'acces_handicapes': 'disability_accesses',
            'positionnement_quartile_1': 'first_quartile',
            'positionnement_quartiles_autres': 'other_quartiles',
            'public_prioritaire': 'priority_public',
            'ref_convention_reservation': 'reservation_agreement_ref', # missing from import
            'raison_sociale_reservataire': 'reserving_business_name',
            'libelle_agence': 'agency_name',
            'contact_a_afficher': 'lessor_contact_name',
            'email_a_afficher': 'lessor_email',
            'telephone_a_afficher': 'lessor_phone_number',
            'id_externe_pdv': 'agency_id',
            'reference_MAD': 'reference_mad'
          }
        end

        def orientations_bailleur
          main_object&.lessor_orientations
        end 
        
        def cave
          main_object&.has_cellar ? 'O' : 'N'
        end 

        def reserving_business_name
          main_object.reservation_holder&.name
        end 

        def id_rpls
          main_object&.rpls_id
        end
        
        def code_residence
          main_object&.is_from_form ? main_object&.als_id : main_object&.residence_code
        end

        def SIREN_ALS
          main_object&.als_siren || "824541148"
        end

        def   charges_locatives
          main_object.rental_charges&.round(2)
        end

        def adresse
          main_object&.address&.slice(0, 38)
        end
        
        def adresse_complement
          main_object&.address_complements&.slice(0, 38)
        end
        
        def ville
          main_object&.district || main_object&.city
        end
        
        def plafond_ressources
          main_object&.threshold&.codes&.fetch(0)
        end
        
        def visite_virtuelle
          main_object&.virtual_visit ? 'O' : 'N'
        end
        
        def meuble
          main_object&.furnished_lodging ? 'O' : 'N'
        end
        
        def balcon_terrasse
          main_object&.terraces_or_balconies ? 'O' : 'N'
        end
        
        def SIREN_bailleur

          main_object&.lessor&.siren&.slice(0, 9) ||main_object&.lessor&.siret&.slice(0, 9)

        end
        
        def SIREN_reservataire
          main_object&.reserving_siren
        end
        
        def libelle_organisme
          main_object&.lessor&.title
        end
        
        def libelle_agence
          main_object&.agency&.title
        end
        
        def statut
          'RBA'
        end
        
        def loyer_mensuel_cc
          main_object&.rent_with_charges&.round(2)
        end
        
        # def libelle_agence
        #   main_object&.agency&.title
        # end
        def espace_vert
          main_object&.green_area ? 'O' : 'N'
        end
        
        def deja_loue
          main_object&.already_inhabited ? 'O' : 'N'
        end
        
        def communiquer_adresse_exacte
          main_object&.communicate_exact_address ? 'O' : 'N'
        end
        
        def copropriete
          return if main_object&.condo.nil?
          
          main_object&.condo ? 'O' : 'N'
        end
        
        def QPV
          main_object&.qpv ? 'O' : 'N'
        end
        
        def jardin
          main_object&.has_garden ? 'O' : 'N'
        end
        
        def ascenseur
          main_object&.has_elevator ? 'O' : 'N'
        end
        
        def duplex
          main_object&.duplex ? 'O' : 'N'
        end
        
        def presence_gardien
          main_object&.has_gardian ? 'O' : 'N'
        end
        
        def annee_construction
          main_object&.construction_year ? main_object&.construction_year.year : nil
        end
        
        def etage
          main_object&.floor || 0
        end
        
        def nb_etage
          main_object&.floors
        end
        
        def nbr_salle_bain
          main_object&.bathrooms || 1
        end
        
        def nb_pieces_logement
          main_object&.rooms || 1
        end
        
        def depot_garantie
          main_object&.guarantee_deposit || 0
        end
        
        def address
          main_object&.address
        end
        
        def postal_code
          main_object&.postal_code
        end
        
        def district
          main_object&.district
        end
        
        def country
          main_object&.country
        end
        
        def latitude
          main_object&.latitude&.to_s&.slice(0, 11)
        end
        
        def longitude
          main_object&.longitude&.to_s&.slice(0, 11)
        end
        
        def loyer_stationnement_cc
          res = main_object&.parking_charges
          res if res && res != 0.0 && res != '0.0'
        end
        
        def date_disponibilite
          main_object&.availability_date&.to_date
        end
        
        def date_fin_designation
          main_object&.designation_date_end&.to_date
        end
        
        def date_MAD_ALS
          main_object&.is_mad_updated_at&.to_date
        end
        
        def surface
          main_object&.surface || 0
        end
        
        def photos
          photos = []
          main_object&.ordered_pictures&.each do |_picture|
            # photos.push(Asset.public_relative_url(picture.full_size_id.to_s).to_s) if (picture.full_size_id)
            photos.push('pat_FRAM.jpg')
          end
          photos
        end
      end
    end
  end
end
