# frozen_string_literal: true

require 'rails_helper'
require 'vcr_config'

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'complementDemandeImhoweb.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::SupplementRequestTask, type: :helper do
  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:app) { create(:applicant)}
    let!(:hr) { create(:housing_request, is_active: true, main_applicant: app) }
    let!(:nud) {create(:nud, housing_request: hr, unique_number: '123456789012345678')}

    let!(:task) do
      build(
        :supplement_request_task,
        options: { housing_request_id: hr.id }
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        task.validate_xml
        ap task.to_xml
        ap xsd.validate(Nokogiri::XML(task.to_xml))
        expect(xsd.validate(Nokogiri::XML(task.to_xml)).length).to eq(0)

        # VCR.use_cassette("supplement_request", :match_requests_on => [:method, :uri, :path]) do
        #   drain_all_jobs
        # end

      end
    end
  end
end
