require 'rails_helper'

RSpec.describe Hermes::Threshold, type: :model do
  let!(:threshold1) do
    create(
        :threshold,
        type: 'Plafond 0',
        thresholds_map: {
            'Paris et communes limitrophes': {
                'thresholds_list': [
                    13_050,
                    21_272,
                    27_883,
                    30_521,
                    36_307,
                    40_859
                ],
                'floors_list': [ 0, 0, 0, 0, 0],
                'another_person': 4552
            },
        }
    )
  end

  let!(:threshold2) do
    create(
      :threshold,
      type: 'Plafond nil',
      thresholds_map: {
        'Paris et communes limitrophes': {
          'thresholds_list': [
            13_050,
            21_272,
            27_883,
            30_521,
            36_307,
            40_859
          ],
          'floors_list': [ nil, nil, nil ,nil ,nil ,nil],
          'another_person': 4552
        },
      }
    )
  end

  let!(:threshold3) do
    create(
      :threshold,
      type: 'Plafond absent',
      thresholds_map: {
        'Paris et communes limitrophes': {
          'thresholds_list': [
            13_050,
            21_272,
            27_883,
            30_521,
            36_307,
            40_859
          ],
          'another_person': 4552
        },
      }
    )
  end

  let!(:threshold4) do
    create(
      :threshold,
      type: 'Plafond renseignés',
      thresholds_map: {
        'Paris et communes limitrophes': {
          'thresholds_list': [
            13_050,
            21_272,
            27_883,
            30_521,
            36_307,
            40_859
          ],
          'floors_list': [ 1, 2, 3 ,4 ,5 ,6],
          'another_person': 4552
        },
      }
    )
  end

  let!(:offer1) {create(:housing_offer, threshold_type: threshold1.type, threshold_subtype: 'Paris et communes limitrophes')}
  let!(:offer2) {create(:housing_offer, threshold_type: threshold2.type, threshold_subtype: 'Paris et communes limitrophes')}
  let!(:offer3) {create(:housing_offer, threshold_type: threshold3.type, threshold_subtype: 'Paris et communes limitrophes')}
  let!(:offer4) {create(:housing_offer, threshold_type: threshold4.type, threshold_subtype: 'Paris et communes limitrophes')}
    
  describe 'plafond a 0' do 
    it 'right floor' do
      [offer1, offer2, offer3].each do |offer|
        expect(offer.ceil_category_1).to eq 13050
        (1..12).each do |i|
          expect(offer["floor_category_#{i}"]).to eq 0
        end
      end 
    end 
  end 
  
  describe 'Plafond renseigné' do 
    it 'right floor' do

      (1..6).each do |i|
        expect(offer4["floor_category_#{i}"]).to eq i
      end

      another_person = threshold4.thresholds_map[:'Paris et communes limitrophes'][:'another_person']

      (7..12).each do |i|
        j = i - 6
        expect(offer4["floor_category_#{i}"]).to eq (j * another_person) + offer4.floor_category_6
      end

    end
  end 
end